@@ -134,15 +134,14 @@ class ClusteringOptimizer:
 		if by.startswith('silhouette'):
 			return max(self._silhouette_scores, key=self._silhouette_scores.get)
 
-		if by.startswith('inertia'):
+		elif by.startswith('inertia'):
 			y_dictionary = self._inertias
 
 		elif by.startswith('distort'):
 			y_dictionary = self._distortions
 
 		else:
-			y_dictionary = None
-			ValueError(f'Method "{by}" is not supported!')
+			raise ValueError(f'Method "{by}" is not supported!')
 
 		# Elbow method
 		y1, y2 = y_dictionary[x1], y_dictionary[x2]
